function [bvp,info]=setBVPPoisson2D_ex03(N,verbose)
  assert(isscalar(N) & N>=2)
  if nargin<=1, verbose=0;end
  dim=2;d=2;
  uex=@(x,y) cos(2*x+y);
  f=@(x,y) 5*cos(2*x+y);
  gradu{1}=@(x,y) -2*sin(2*x+y);
  gradu{2}=@(x,y) -sin(2*x+y);
  ar3=@(x,y) 1+x.^2+y.^2;
  if verbose>=1
    fprintf('------------------------------------------------------\n'); 
    fprintf('      2D Poisson BVP problem on unit square\n');
    fprintf('               - Delta(u) = f\n')
    fprintf(' with exact solution : %s\n',func2str(uex));
    fprintf(' and boundary conditions :\n');
    fprintf('   * Dirichlet on [1,2]\n');
    fprintf('       u = gD \n');
    fprintf('   * Robin boundary condition on [3]\n');
    fprintf('       du/dn + ar*u = gR\n');
    fprintf('         with ar=%s\n',func2str(ar3));
    fprintf('   * Neumann boundary condition on [4]\n');
    fprintf('       du/dn = gN\n');
    fprintf('------------------------------------------------------\n');
    if verbose==10, return;end
  end
  if verbose>=2,fprintf('1. Setting the mesh using HyperCube function\n');end
  tstart=tic();
  Th=fc_simesh.HyperCube(2,N);
  tcpu(1)=toc(tstart);
  if verbose>=2
    fprintf('     Mesh sizes : nq=%d, h=%.3e\n',Th.nq,Th.get_h());
    fprintf('2. Setting 2D Poisson BVP problem\n');
  end
  tstart=tic();
  Lop=Loperator(dim,d,{1,0;0,1},[],[],[]);
  pde=PDEelt(Lop,f);
  bvp=BVP(Th,pde);
  bvp.setDirichlet( 1, uex);
  bvp.setDirichlet( 2, uex);
  bvp.setRobin( 3, @(x,y)  -gradu{2}(x,y)+ar3(x,y).*uex(x,y),ar3);
  bvp.setRobin( 4, gradu{2},[]);
  tcpu(2)=toc(tstart);

  info.solex=uex;
  info.f=f;
  info.gradu=gradu;
  info.ar3=ar3;
  info.tcpu=tcpu;
end